/***********************************************************************************
FILE NAME  	: uart0.c

DESCRIPTION	: Demonstration of SCI0 in asynchronous mode.
		      This program communicates from the SH2/7086 to a terminal program via
		      SCI0 and RS232.
		      SCI0 configuration is: 19200 baud, 8 data bits, 1 stop bit, no parity.

OPERATION   : 1. Build this application and download it to the target. Press 'Reset Go'.
			  2. Following message will be displayed on the terminal window:
						Renesas Technology Corporation
						RSKSH7086 UART demo.
						Press z to stop, any key to continue.

			  3. Incrementing data (0 to 9) will be sent to the terminal window.
 			  4. To stop receiving data, press 'z' on the keyboard. To resume, press
			     any key other than 'z'.
			  5. While data is being transmitted, LED0 is ON and LED1 is OFF. When
			     transmission is stopped by pressing "z" LED1 turns ON and LED0 turns OFF.

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
16.08.2011 modified by syslab
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/

/**********************************************************************************
User Includes
***********************************************************************************/
/*	Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include "intrinsics.h"
/* Following header file provides a structure to access all of the device registers.*/
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "syslab7086def.h"
/* Following header file provides prototype for the functions defined in this file.*/
#include "uart.h"
/*	Following header file provides vector locations for the interrupts. */
#include "inthandler.h"

#ifdef UART0
/**********************************************************************************
Global variables
***********************************************************************************/
/* Global initialised variable*/
unsigned char uart0_in;


/**********************************************************************************
User Program Code
***********************************************************************************/

/**********************************************************************************
Function Name: 	SCI0_Init
Description:	Initializes SCI0
Parameters: 	none
Return value: 	none
***********************************************************************************/
void SCI0_Init(void)
{
	int	i;

	/* Enable SCI_0 module */
	STB.CR3.BIT._SCI0 = 0;

	/*Setting port A I/O register L (PAIORL) */
	PFC.PAIORL.BIT.B1 = 1;

	/* Port pin PA1 is configured as TXD0 Output */
	PFC.PACRL1.BIT.PA1MD = 1;

	/* Port pin PA0 is configured as RXD0 Input */
	PFC.PACRL1.BIT.PA0MD = 1;


	/* SCSCR Zero Clear */
	SCI0.SCSCR.BYTE = 0;
	SCI0.SCSSR.BYTE = 0;

	/* Setting of Transmission/Reception Format
	   ASYNC Mode, 8bit data, None parity bit, 1 stop bit, P/1 clock */
	SCI0.SCSMR.BYTE = 0;


	/* Setting of Bit Rate: 19200 bps at 40 MHz peripheral clock.*/
	SCI0.SCBRR = 0x40;

	/* Wait for SCI Setting (1 bit cycle) */
	for(i=0 ; i<3000 ; i++);


	/*	Set interrupt priority od SCI_0 other than 0 in order to enbale interrupt. */
	INTC.IPRL.BIT._SCI0 = 0x02;

	/* Recieve Interrupt Enable (RIE = 1 ) */
	/* Transmission/Reception Enable (TE = 1, RE = 1) */
	SCI0.SCSCR.BYTE = 0x70;

}
/**********************************************************************************
End of function SCI0_Init
***********************************************************************************/

/**********************************************************************************
Function Name: 	SCI0_text_write
Description:	The following sends a text string to the terminal program
Parameters: 	msg_string -> the text string to output
Return value: 	none
***********************************************************************************/
void SCI0_text_write (char * msg_string)
{
	char i;

	/* This loop reads in the text string and puts it in the UART 0 transmit buffer */
	for (i=0; msg_string[(int)i]; i++)
	{
		while(SCI0.SCSSR.BIT.TDRE == 0);
		SCI0.SCTDR = msg_string[(int)i];

		/* set 0 to TDRE */
		SCI0.SCSSR.BIT.TDRE = 0;

	}
}
/**********************************************************************************
End of function SCI0_text_write
***********************************************************************************/
/**********************************************************************************
Function Name: 	INT_SCI0_RXI0
Description:	SCI0_RXI0 Interrupt
Parameters: 	none
Return value: 	none
***********************************************************************************/
void INT_SCI0_RXI0(void)
{
	if(SCI0.SCSSR.BIT.RDRF == 1)
	{
		uart0_in = SCI0.SCRDR;
		SCI0.SCSSR.BIT.RDRF = 0;
		if (uart0_in == 'z')
		{
			while(SCI0.SCSSR.BIT.TDRE == 0);

			SCI0.SCTDR = 'z';

			/* TDRE Zero Clear */
			SCI0.SCSSR.BIT.TDRE = 0;

			LED1 = LED_ON;
			LED0 = LED_OFF;
		}
	}
}
/**********************************************************************************
End of function INT_SCI0_RXI0
***********************************************************************************/
#endif
/**********************************************************************************
End of file
***********************************************************************************/
