/***********************************************************************************
FILE NAME  	: uart1.c

DESCRIPTION	: Demonstration of SCI1 in asynchronous mode.
		      This program communicates from the SH2/7086 to a terminal program via
		      SCI1 and RS232.
		      SCI1 configuration is: 19200 baud, 8 data bits, 1 stop bit, no parity.

OPERATION   : 1. Build this application and download it to the target. Press 'Reset Go'.
			  2. Following message will be displayed on the terminal window:
						Renesas Technology Corporation
						RSKSH7086 UART demo.
						Press z to stop, any key to continue.

			  3. Incrementing data (0 to 9) will be sent to the terminal window.
 			  4. To stop receiving data, press 'z' on the keyboard. To resume, press
			     any key other than 'z'.
			  5. While data is being transmitted, LED0 is ON and LED1 is OFF. When
			     transmission is stopped by pressing "z" LED1 turns ON and LED0 turns OFF.

Copyright   : 2006 Renesas Technology Europe Ltd.
			  2006 Renesas Technology Corporation.
			  All Rights Reserved
***********************************************************************************/

/***********************************************************************************
Revision History
DD.MM.YYYY OSO-UID Description
06.12.2006 RTE-NPS First Release.
16.08.2011 modified by syslab
***********************************************************************************/

/***********************************************************************************
System Includes
***********************************************************************************/

/**********************************************************************************
User Includes
***********************************************************************************/
/*	Following header file provides access to intrinsic functions to control interrupt
	levels. */
#include "intrinsics.h"
/* Following header file provides a structure to access all of the device registers.*/
#include "iodefine.h"
/* Following header file provides common defines for widely used items. */
#include "syslab7086def.h"
/* Following header file provides prototype for the functions defined in this file.*/
#include "uart.h"
/*	Following header file provides vector locations for the interrupts. */
#include "inthandler.h"

#ifdef UART1
/**********************************************************************************
Global variables
***********************************************************************************/
/* Global initialised variable*/
unsigned char uart1_in;


/**********************************************************************************
User Program Code
***********************************************************************************/

/**********************************************************************************
Function Name: 	SCI1_Init
Description:	Initializes SCI1
Parameters: 	none
Return value: 	none
***********************************************************************************/
void SCI1_Init(void)
{
	int	i;

	/* Enable SCI_1 module */
	STB.CR3.BIT._SCI1 = 0;

	/*Setting port A I/O register L (PAIORL) */
	PFC.PAIORL.BIT.B4 = 1;

	/* Port pin PA4 is configured as TXD1 Output */
	PFC.PACRL2.BIT.PA4MD = 1;

	/* Port pin PA3 is configured as RXD1 Input */
	PFC.PACRL1.BIT.PA3MD = 1;


	/* SCSCR Zero Clear */
	SCI1.SCSCR.BYTE = 0;
	SCI1.SCSSR.BYTE = 0;

	/* Setting of Transmission/Reception Format
	   ASYNC Mode, 8bit data, None parity bit, 1 stop bit, P/1 clock */
	SCI1.SCSMR.BYTE = 0;


	/* Setting of Bit Rate: 19200 bps at 40 MHz peripheral clock.*/
	SCI1.SCBRR = 0x40;

	/* Wait for SCI Setting (1 bit cycle) */
	for(i=0 ; i<3000 ; i++);


	/*	Set interrupt priority od SCI_1 other than 0 in order to enbale interrupt. */
	INTC.IPRL.BIT._SCI1 = 0x02;

	/* Recieve Interrupt Enable (RIE = 1 ) */
	/* Transmission/Reception Enable (TE = 1, RE = 1) */
	SCI1.SCSCR.BYTE = 0x70;

}
/**********************************************************************************
End of function SCI1_Init
***********************************************************************************/

/**********************************************************************************
Function Name: 	SCI1_text_write
Description:	The following sends a text string to the terminal program
Parameters: 	msg_string -> the text string to output
Return value: 	none
***********************************************************************************/
void SCI1_text_write (char * msg_string)
{
	char i;

	/* This loop reads in the text string and puts it in the UART 0 transmit buffer */
	for (i=0; msg_string[(int)i]; i++)
	{
		while(SCI1.SCSSR.BIT.TDRE == 0);
		SCI1.SCTDR = msg_string[(int)i];

		/* set 0 to TDRE */
		SCI1.SCSSR.BIT.TDRE = 0;

	}
}
/**********************************************************************************
End of function SCI1_text_write
***********************************************************************************/
/**********************************************************************************
Function Name: 	INT_SCI1_RXI1
Description:	SCI1_RXI1 Interrupt
Parameters: 	none
Return value: 	none
***********************************************************************************/
void INT_SCI1_RXI1(void)
{
	if(SCI1.SCSSR.BIT.RDRF == 1)
	{
		uart1_in = SCI1.SCRDR;
		SCI1.SCSSR.BIT.RDRF = 0;
		if (uart1_in == 'z')
		{
			while(SCI1.SCSSR.BIT.TDRE == 0);

			SCI1.SCTDR = 'z';

			/* TDRE Zero Clear */
			SCI1.SCSSR.BIT.TDRE = 0;

			LED1 = LED_ON;
			LED0 = LED_OFF;
		}
	}
}
/**********************************************************************************
End of function INT_SCI1_RXI1
***********************************************************************************/
#endif
/**********************************************************************************
End of file
***********************************************************************************/
